﻿
VERSION = '1.00'

import BeautifulSoup
import postmarkup
from pygments import highlight
from pygments.lexers import get_lexer_by_name
from pygments.formatters import HtmlFormatter
from pygments.styles import get_style_by_name
from copy import deepcopy
import HTMLParser


 

class PygmentsCodeTag(postmarkup.PygmentsCodeTag):
    def render_open(self, parser, node_index):
        contents = self.get_contents(parser)
        self.skip_contents(parser)
        lexer = get_lexer_by_name("python", stripall=True)
        #  'emacs', 'friendly', 'colorful']
        formatter = HtmlFormatter(linenos=False, cssclass="source")
        formatter.noclasses = True
        p = u'<br><div style="font-size:8;color:#999999;background:#FCBB9A"><em>code-python:\n</em></div>'
        return p+highlight(contents, lexer, formatter)
        
class LeftTag(postmarkup.CenterTag):
    def render_open(self, parser, node_index, **kwargs):
        return u'<div style="text-align:left;">'           
class RightTag(postmarkup.CenterTag):
    def render_open(self, parser, node_index, **kwargs):
        return u'<div style="text-align:right;">'        
class HTag(postmarkup.CenterTag):
    def render_open(self, parser, node_index, **kwargs):
        return u'<div style="font-size:15;color:#999999;">    '
class GoTag(postmarkup.LinkTag):
    
    def render_open(self, parser, node_index):
        self.annotate_links = 0
        self.domain = u''
        tag_data = parser.tag_data
        nest_level = tag_data['link_nest_level'] = tag_data.setdefault('link_nest_level', 0) + 1

        if nest_level > 1:
            return u""

        if self.params:
            url = self.params.strip()
        else:
            url = self.get_contents_text(parser).strip()
            url = postmarkup._unescape(url)

        self.domain = ""

        if u"javascript:" in url.lower():
            return ""

        if ':' not in url:
            url = 'go://' + url

        scheme, uri = url.split(':', 1)

        if scheme not in ['go']:
            return u''

        try:
            domain = self._re_domain.search(uri.lower()).group(1)
        except IndexError:
            return u''

        domain = domain.lower()
        if domain.startswith('www.'):
            domain = domain[4:]

        def percent_encode(s):
            safe_chars = self._safe_chars
            def replace(c):
                if c not in safe_chars:
                    return "%%%02X"%ord(c)
                else:
                    return c
            return "".join([replace(c) for c in s])

        self.url = percent_encode(url.encode('utf-8', 'replace'))
        self.domain = domain

        if not self.url:
            return u""

        if self.domain:
            return u'<a href="%s">'%self.url
        else:
            return u""    

            
parsHTML = HTMLParser.HTMLParser()
my_postmarkup = postmarkup.create(use_pygments=0 ,annotate_links=False)
my_postmarkup.add_tag(PygmentsCodeTag,'code')
my_postmarkup.add_tag(RightTag,'right')
my_postmarkup.add_tag(GoTag,'go')
my_postmarkup.add_tag(HTag,'h')


def BBcode2HTML(text):
    return my_postmarkup(text)
    
def HTML2MyData(html):    
    soup = BeautifulSoup.BeautifulSoup(html)  
    out = []      
    for s in soup:
        findstr(s,out,[])    
    return out    
    
    
def BBcode2MyData(text):
    html =  my_postmarkup(text) 
    return HTML2MyData(html)
    
    
    
def _getDictStyle(style):
    d = {}
    for el in style:
        if el[0] == 'style':
            for param in el[1].split(';'):
                #print 'param',param
                try:
                    key,val = param.split(':')
                    d[ key.strip()] =  val.strip()
                except ValueError, e:
                    #print 'except ValueError',e,'\nin->',[param]
                    pass
                    
        else:
            d[ el[0]] =  el[1] 
    
    return d


def findstr(s,out,style):
    if isinstance(s,BeautifulSoup.Tag):
        if s.name == 'img':
            d = _getDictStyle(style)
            d['text']= ""
            d['src']= s.attrs[0][1]
            out.append(d) 
        if s.name == 'br':
                out.append({'text':'\n'})
                
        for x in s:
            findstr(x,out,deepcopy(style)+s.attrs+ [(s.name,1)])
    else:
        text = unicode(s)
        #print
        #print text
        #print style
        d = _getDictStyle(style)
        d['text']= parsHTML.unescape(text)
        out.append(d)
        
        
if __name__ == '__main__':
    pass 

        








